@@ -1,14 +1,14 @@
 # Copyrights 2001-2008 by Mark Overmeer.
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 1.04.
+# Pod stripped from pm file by OODoc 1.05.
 
 use strict;
 use warnings;
 
 package Mail::Message::TransferEnc::Binary;
 use vars '$VERSION';
-$VERSION = '2.082';
+$VERSION = '2.086';
 
 use base 'Mail::Message::TransferEnc';
 
@@ -38,7 +38,7 @@ sub encode($@)
     my @lines;
 
     my $changes = 0;
-    foreach ($self->lines)
+    foreach ($body->lines)
     {   $changes++ if s/[\000\013]//g;
         push @lines, $_;
     }
